using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.Diagnostics;
using System.Text;

using Syncfusion.XlsIO;
using Syncfusion.XlsIO.Implementation;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Tools;
using Syncfusion.Drawing;
using Syncfusion.GridExcelConverter;

namespace ComboGDBG
{
	/// <summary>
	/// Summary description for ADVExcelExport.
	/// </summary>
	public class ADVExcelExportControl: GridExcelConverterControl
	{
		public ADVExcelExportControl():base()
		{
		}
		public void ExcelExport(GridModel model,string FileName, bool IsCreateNew)
		{
			ExcelEngine engine = CreateEngine();
			IWorkbook book = (!IsCreateNew)? engine.Excel.Workbooks.Open(FileName):engine.Excel.Workbooks.Create();
			IWorksheet sheet = book.Worksheets[ 0 ];
			GridRangeInfoList list = model.SelectedRanges;
			GridRangeInfo range;
			for (int row = 0; row <= model.RowCount; row++ )
			{
				for (int col = 0; col <= model.ColCount; col++ )
				{
					ExportCells(GridRangeInfo.Cell(row,col),model,sheet);
				}
			}
			book.SaveAs(FileName);  
			book.Close(); 
		}

		public void SelectedCellsExport(GridModel model,string FileName)
		{
			ExcelEngine engine = CreateEngine();
			IWorkbook book = engine.Excel.Workbooks.Create( 1 );
			IWorksheet sheet = book.Worksheets[ 0 ];
			GridRangeInfoList list = model.SelectedRanges;
			GridRangeInfo range;
			for (int ctr = list.Count - 1; ctr >= 0; ctr-- )
			{
				range = list[ctr];

				switch( range.RangeType)
				{
					case GridRangeInfoType.Cells:  
						ExportCells(range,model,sheet);
						break;
					case GridRangeInfoType.Cols:  
						ExportCells(GridRangeInfo.Cells(1,range.Left,model.RowCount,range.Right),model,sheet);    
						break;
					case GridRangeInfoType.Rows:  
						ExportCells(GridRangeInfo.Cells(range.Top,1,range.Bottom,model.ColCount),model,sheet);
						break;

				}
			}
			book.SaveAs(FileName);  
			book.Close(); 
		}

		public void CurrentCellExport(GridModel model,string FileName,GridCurrentCell CurrentCell, bool IsCreateNew )
		{
			ExcelEngine engine = CreateEngine();

			IWorkbook book = (!IsCreateNew)? engine.Excel.Workbooks.Open(FileName):engine.Excel.Workbooks.Create();
			IWorksheet sheet = book.Worksheets[ 0 ];
			GridRangeInfoList list = model.SelectedRanges;
			ExportCurrentCell(CurrentCell,model,sheet);
			book.SaveAs(FileName);  
			book.Close(); 
		}
		public void ExportCurrentCell(GridCurrentCell CurrentCell, GridModel model, IWorksheet sheet)
		{
			this.CopyStyle( model[CurrentCell.RowIndex, CurrentCell.ColIndex],sheet[CurrentCell.RowIndex + 1, CurrentCell.ColIndex]);
			sheet[CurrentCell.RowIndex + 1 , CurrentCell.ColIndex].Text = model[CurrentCell.RowIndex, CurrentCell.ColIndex].FormattedText;
		}


		public void ExportCells(GridRangeInfo range, GridModel model, IWorksheet sheet)
		{
			for(int i = range.Top, iRowRange = 1 ;i<= range.Bottom;i++,iRowRange++)
			{
				for(int j = range.Left,iColRange = 1 ;j<= range.Right;j++,iColRange++)
				{
					this.CopyStyle( model[i,j],sheet[iRowRange,iColRange]);
					sheet[iRowRange,iColRange].Text = model[i,j].FormattedText; 
				}
			}
		}
			
		
	}
}
